@@ -95,8 +95,7 @@ def _application_code(code: grpc.StatusCode) -> cygrpc.StatusCode:
 def _completion_code(state: _RPCState) -> cygrpc.StatusCode:
     if state.code is None:
         return cygrpc.StatusCode.ok
-    else:
-        return _application_code(state.code)
+    return _application_code(state.code)
 
 
 def _abortion_code(
@@ -104,8 +103,7 @@ def _abortion_code(
 ) -> cygrpc.StatusCode:
     if state.code is None:
         return code
-    else:
-        return _application_code(state.code)
+    return _application_code(state.code)
 
 
 def _details(state: _RPCState) -> bytes:
@@ -230,8 +228,7 @@ def _possibly_finish_call(
         callbacks = state.callbacks
         state.callbacks = None
         return state, callbacks
-    else:
-        return None, ()
+    return None, ()
 
 
 def _send_status_from_server(state: _RPCState, token: str) -> ServerCallbackTag:
@@ -254,10 +251,8 @@ def _get_initial_metadata(
             )
             if metadata is None:
                 return compression_metadata
-            else:
-                return compression_metadata + tuple(metadata)
-        else:
-            return metadata
+            return compression_metadata + tuple(metadata)
+        return metadata
 
 
 def _get_initial_metadata_operation(
@@ -395,9 +390,8 @@ class _Context(grpc.ServicerContext):
         with self._state.condition:
             if self._state.callbacks is None:
                 return False
-            else:
-                self._state.callbacks.append(callback)
-                return True
+            self._state.callbacks.append(callback)
+            return True
 
     def disable_next_message_compression(self) -> None:
         with self._state.condition:
@@ -432,19 +426,18 @@ class _Context(grpc.ServicerContext):
         with self._state.condition:
             if self._state.client is _CANCELLED:
                 _raise_rpc_error(self._state)
+            if self._state.initial_metadata_allowed:
+                operation = _get_initial_metadata_operation(
+                    self._state, initial_metadata
+                )
+                self._rpc_event.call.start_server_batch(
+                    (operation,), _send_initial_metadata(self._state)
+                )
+                self._state.initial_metadata_allowed = False
+                self._state.due.add(_SEND_INITIAL_METADATA_TOKEN)
             else:
-                if self._state.initial_metadata_allowed:
-                    operation = _get_initial_metadata_operation(
-                        self._state, initial_metadata
-                    )
-                    self._rpc_event.call.start_server_batch(
-                        (operation,), _send_initial_metadata(self._state)
-                    )
-                    self._state.initial_metadata_allowed = False
-                    self._state.due.add(_SEND_INITIAL_METADATA_TOKEN)
-                else:
-                    error_msg = "Initial metadata no longer allowed!"
-                    raise ValueError(error_msg)
+                error_msg = "Initial metadata no longer allowed!"
+                raise ValueError(error_msg)
 
     def set_trailing_metadata(self, trailing_metadata: MetadataType) -> None:
         with self._state.condition:
@@ -561,34 +554,33 @@ def _unary_request(
         with state.condition:
             if not _is_rpc_state_active(state):
                 return None
-            else:
-                rpc_event.call.start_server_batch(
-                    (cygrpc.ReceiveMessageOperation(_EMPTY_FLAGS),),
-                    _receive_message(
-                        state, rpc_event.call, request_deserializer
-                    ),
-                )
-                state.due.add(_RECEIVE_MESSAGE_TOKEN)
-                while True:
-                    state.condition.wait()
-                    if state.request is None:
-                        if state.client is _CLOSED:
-                            details = '"{}" requires exactly one request message.'.format(
+            rpc_event.call.start_server_batch(
+                (cygrpc.ReceiveMessageOperation(_EMPTY_FLAGS),),
+                _receive_message(state, rpc_event.call, request_deserializer),
+            )
+            state.due.add(_RECEIVE_MESSAGE_TOKEN)
+            while True:
+                state.condition.wait()
+                if state.request is None:
+                    if state.client is _CLOSED:
+                        details = (
+                            '"{}" requires exactly one request message.'.format(
                                 rpc_event.call_details.method
                             )
-                            _abort(
-                                state,
-                                rpc_event.call,
-                                cygrpc.StatusCode.unimplemented,
-                                _common.encode(details),
-                            )
-                            return None
-                        elif state.client is _CANCELLED:
-                            return None
-                    else:
-                        request = state.request
-                        state.request = None
-                        return request
+                        )
+                        _abort(
+                            state,
+                            rpc_event.call,
+                            cygrpc.StatusCode.unimplemented,
+                            _common.encode(details),
+                        )
+                        return None
+                    if state.client is _CANCELLED:
+                        return None
+                else:
+                    request = state.request
+                    state.request = None
+                    return request
 
     return unary_request
 
@@ -697,8 +689,7 @@ def _serialize_response(
                 b"Failed to serialize response!",
             )
         return None
-    else:
-        return serialized_response
+    return serialized_response
 
 
 def _get_send_message_op_flags_from_state(
@@ -706,8 +697,7 @@ def _get_send_message_op_flags_from_state(
 ) -> Union[int, cygrpc.WriteFlag]:
     if state.disable_next_compression:
         return cygrpc.WriteFlag.no_compress
-    else:
-        return _EMPTY_FLAGS
+    return _EMPTY_FLAGS
 
 
 def _reset_per_message_state(state: _RPCState) -> None:
@@ -721,34 +711,33 @@ def _send_response(
     with state.condition:
         if not _is_rpc_state_active(state):
             return False
-        else:
-            if state.initial_metadata_allowed:
-                operations = (
-                    _get_initial_metadata_operation(state, None),
-                    cygrpc.SendMessageOperation(
-                        serialized_response,
-                        _get_send_message_op_flags_from_state(state),
-                    ),
-                )
-                state.initial_metadata_allowed = False
-                token = _SEND_INITIAL_METADATA_AND_SEND_MESSAGE_TOKEN
-            else:
-                operations = (
-                    cygrpc.SendMessageOperation(
-                        serialized_response,
-                        _get_send_message_op_flags_from_state(state),
-                    ),
-                )
-                token = _SEND_MESSAGE_TOKEN
-            rpc_event.call.start_server_batch(
-                operations, _send_message(state, token)
+        if state.initial_metadata_allowed:
+            operations = (
+                _get_initial_metadata_operation(state, None),
+                cygrpc.SendMessageOperation(
+                    serialized_response,
+                    _get_send_message_op_flags_from_state(state),
+                ),
             )
-            state.due.add(token)
-            _reset_per_message_state(state)
-            while True:
-                state.condition.wait()
-                if token not in state.due:
-                    return _is_rpc_state_active(state)
+            state.initial_metadata_allowed = False
+            token = _SEND_INITIAL_METADATA_AND_SEND_MESSAGE_TOKEN
+        else:
+            operations = (
+                cygrpc.SendMessageOperation(
+                    serialized_response,
+                    _get_send_message_op_flags_from_state(state),
+                ),
+            )
+            token = _SEND_MESSAGE_TOKEN
+        rpc_event.call.start_server_batch(
+            operations, _send_message(state, token)
+        )
+        state.due.add(token)
+        _reset_per_message_state(state)
+        while True:
+            state.condition.wait()
+            if token not in state.due:
+                return _is_rpc_state_active(state)
 
 
 def _status(
@@ -890,8 +879,7 @@ def _select_thread_pool_for_behavior(
         behavior.experimental_thread_pool, futures.ThreadPoolExecutor
     ):
         return behavior.experimental_thread_pool
-    else:
-        return default_thread_pool
+    return default_thread_pool
 
 
 def _handle_unary_unary(
@@ -1014,8 +1002,7 @@ def _find_method_handler(
         return state.context.run(
             interceptor_pipeline.execute, query_handlers, handler_call_details
         )
-    else:
-        return state.context.run(query_handlers, handler_call_details)
+    return state.context.run(query_handlers, handler_call_details)
 
 
 def _reject_rpc(
@@ -1057,19 +1044,16 @@ def _handle_with_method_handler(
                 return _handle_stream_stream(
                     rpc_event, state, method_handler, thread_pool
                 )
-            else:
-                return _handle_stream_unary(
-                    rpc_event, state, method_handler, thread_pool
-                )
-        else:
-            if method_handler.response_streaming:
-                return _handle_unary_stream(
-                    rpc_event, state, method_handler, thread_pool
-                )
-            else:
-                return _handle_unary_unary(
-                    rpc_event, state, method_handler, thread_pool
-                )
+            return _handle_stream_unary(
+                rpc_event, state, method_handler, thread_pool
+            )
+        if method_handler.response_streaming:
+            return _handle_unary_stream(
+                rpc_event, state, method_handler, thread_pool
+            )
+        return _handle_unary_unary(
+            rpc_event, state, method_handler, thread_pool
+        )
 
 
 def _handle_call(
@@ -1119,7 +1103,7 @@ def _handle_call(
                 b"Method not found!",
             )
             return rpc_state, None
-        elif concurrency_exceeded:
+        if concurrency_exceeded:
             _reject_rpc(
                 rpc_event,
                 rpc_state,
@@ -1127,15 +1111,13 @@ def _handle_call(
                 b"Concurrent RPC limit exceeded!",
             )
             return rpc_state, None
-        else:
-            return (
-                rpc_state,
-                _handle_with_method_handler(
-                    rpc_event, rpc_state, method_handler, thread_pool
-                ),
-            )
-    else:
-        return None, None
+        return (
+            rpc_state,
+            _handle_with_method_handler(
+                rpc_event, rpc_state, method_handler, thread_pool
+            ),
+        )
+    return None, None
 
 
 @enum.unique
@@ -1249,8 +1231,7 @@ def _stop_serving(state: _ServerState) -> bool:
             shutdown_event.set()
         state.stage = _ServerStage.STOPPED
         return True
-    else:
-        return False
+    return False
 
 
 def _on_call_completed(state: _ServerState) -> None:
@@ -1359,22 +1340,21 @@ def _stop(state: _ServerState, grace: Optional[float]) -> threading.Event:
             shutdown_event = threading.Event()
             shutdown_event.set()
             return shutdown_event
+        _begin_shutdown_once(state)
+        shutdown_event = threading.Event()
+        state.shutdown_events.append(shutdown_event)
+        if grace is None:
+            state.server.cancel_all_calls()
         else:
-            _begin_shutdown_once(state)
-            shutdown_event = threading.Event()
-            state.shutdown_events.append(shutdown_event)
-            if grace is None:
-                state.server.cancel_all_calls()
-            else:
 
-                def cancel_all_calls_after_grace():
-                    shutdown_event.wait(timeout=grace)
-                    with state.lock:
-                        state.server.cancel_all_calls()
+            def cancel_all_calls_after_grace():
+                shutdown_event.wait(timeout=grace)
+                with state.lock:
+                    state.server.cancel_all_calls()
 
-                thread = threading.Thread(target=cancel_all_calls_after_grace)
-                thread.start()
-                return shutdown_event
+            thread = threading.Thread(target=cancel_all_calls_after_grace)
+            thread.start()
+            return shutdown_event
     shutdown_event.wait()
     return shutdown_event
 
